@@ -263,6 +263,10 @@ else:
         FastDeployStableDiffusionMegaPipeline,
         FastDeployStableDiffusionPipeline,
         FastDeployStableDiffusionUpscalePipeline,
+        FastDeployStableDiffusionXLPipeline,
+        FastDeployStableDiffusionXLImg2ImgPipeline,
+        FastDeployStableDiffusionXLInpaintPipeline,
+        FastDeployStableDiffusionXLMegaPipeline,
     )
 
 try:
