@@ -389,6 +389,11 @@ class UNet2DConditionModel(ModelMixin, ConfigMixin, UNet2DConditionLoadersMixin)
         else:
             self.time_embed_act = get_activation(time_embedding_act_fn)
 
+        # pre_temb_act_fun opt
+        self.resnet_pre_temb_non_linearity = resnet_pre_temb_non_linearity
+        if resnet_pre_temb_non_linearity:
+            self.down_resnet_temb_nonlinearity = get_activation(act_fn)
+
         self.down_blocks = nn.LayerList([])
         self.up_blocks = nn.LayerList([])
 
@@ -424,11 +429,6 @@ class UNet2DConditionModel(ModelMixin, ConfigMixin, UNet2DConditionLoadersMixin)
         else:
             blocks_time_embed_dim = time_embed_dim
 
-        # pre_temb_act_fun opt
-        self.resnet_pre_temb_non_linearity = resnet_pre_temb_non_linearity
-        if resnet_pre_temb_non_linearity:
-            self.down_resnet_temb_nonlinearity = get_activation(act_fn)
-
         # down
         output_channel = block_out_channels[0]
         for i, down_block_type in enumerate(down_block_types):
@@ -890,6 +890,9 @@ class UNet2DConditionModel(ModelMixin, ConfigMixin, UNet2DConditionLoadersMixin)
 
         emb = emb + aug_emb if aug_emb is not None else emb
 
+        if self.resnet_pre_temb_non_linearity:
+            emb = self.down_resnet_temb_nonlinearity(emb)
+
         if self.time_embed_act is not None:
             emb = self.time_embed_act(emb)
 
@@ -981,7 +984,7 @@ class UNet2DConditionModel(ModelMixin, ConfigMixin, UNet2DConditionLoadersMixin)
             # if we have not reached the final block and need to forward the
             # upsample size, we do it here
             if not is_final_block and forward_upsample_size:
-                upsample_size = down_block_res_samples[-1].shape[2:]
+                upsample_size = paddle.shape(down_block_res_samples[-1])[2:]
 
             if hasattr(upsample_block, "has_cross_attention") and upsample_block.has_cross_attention:
                 sample = upsample_block(
