@@ -81,13 +81,14 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
 
     @register_to_config
     def __init__(
-            self,
-            sigma_min: float=0.02,
-            sigma_max: float=100,
-            s_noise: float=1.007,
-            s_churn: float=80,
-            s_min: float=0.05,
-            s_max: float=50, ):
+        self,
+        sigma_min: float = 0.02,
+        sigma_max: float = 100,
+        s_noise: float = 1.007,
+        s_churn: float = 80,
+        s_min: float = 0.05,
+        s_max: float = 50,
+    ):
         # standard deviation of the initial noise distribution
         self.init_noise_sigma = sigma_max
 
@@ -96,9 +97,7 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
         self.timesteps: paddle.Tensor = None
         self.schedule: paddle.Tensor = None  # sigma(t_i)
 
-    def scale_model_input(self,
-                          sample: paddle.Tensor,
-                          timestep: Optional[int]=None) -> paddle.Tensor:
+    def scale_model_input(self, sample: paddle.Tensor, timestep: Optional[int] = None) -> paddle.Tensor:
         """
         Ensures interchangeability with schedulers that need to scale the denoising model input depending on the
         current timestep.
@@ -124,16 +123,18 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
         self.num_inference_steps = num_inference_steps
         timesteps = np.arange(0, self.num_inference_steps)[::-1].copy()
         self.timesteps = paddle.to_tensor(timesteps)
-        schedule = [(self.config.sigma_max
-                     **2 * (self.config.sigma_min**2 / self.config.sigma_max**2)
-                     **(i / (num_inference_steps - 1))) for i in self.timesteps]
+        schedule = [
+            (
+                self.config.sigma_max**2
+                * (self.config.sigma_min**2 / self.config.sigma_max**2) ** (i / (num_inference_steps - 1))
+            )
+            for i in self.timesteps
+        ]
         self.schedule = paddle.to_tensor(schedule, dtype=paddle.float32)
 
-    def add_noise_to_input(self,
-                           sample: paddle.Tensor,
-                           sigma: float,
-                           generator: Optional[paddle.Generator]=None) -> Tuple[
-                               paddle.Tensor, float]:
+    def add_noise_to_input(
+        self, sample: paddle.Tensor, sigma: float, generator: Optional[paddle.Generator] = None
+    ) -> Tuple[paddle.Tensor, float]:
         """
         Explicit Langevin-like "churn" step of adding noise to the sample according to a factor gamma_i ≥ 0 to reach a
         higher noise level sigma_hat = sigma_i + gamma_i*sigma_i.
@@ -141,26 +142,25 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
         TODO Args:
         """
         if self.config.s_min <= sigma <= self.config.s_max:
-            gamma = min(self.config.s_churn / self.num_inference_steps,
-                        2**0.5 - 1)
+            gamma = min(self.config.s_churn / self.num_inference_steps, 2**0.5 - 1)
         else:
             gamma = 0
 
         # sample eps ~ N(0, S_noise^2 * I)
-        eps = self.config.s_noise * randn_tensor(
-            sample.shape, generator=generator)
+        eps = self.config.s_noise * randn_tensor(sample.shape, generator=generator)
         sigma_hat = sigma + gamma * sigma
-        sample_hat = sample + ((sigma_hat**2 - sigma**2)**0.5 * eps)
+        sample_hat = sample + ((sigma_hat**2 - sigma**2) ** 0.5 * eps)
 
         return sample_hat, sigma_hat
 
     def step(
-            self,
-            model_output: paddle.Tensor,
-            sigma_hat: float,
-            sigma_prev: float,
-            sample_hat: paddle.Tensor,
-            return_dict: bool=True, ) -> Union[KarrasVeOutput, Tuple]:
+        self,
+        model_output: paddle.Tensor,
+        sigma_hat: float,
+        sigma_prev: float,
+        sample_hat: paddle.Tensor,
+        return_dict: bool = True,
+    ) -> Union[KarrasVeOutput, Tuple]:
         """
         Predict the sample at the previous timestep by reversing the SDE. Core function to propagate the diffusion
         process from the learned model outputs (most often the predicted noise).
@@ -188,19 +188,19 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
             return (sample_prev, derivative)
 
         return KarrasVeOutput(
-            prev_sample=sample_prev,
-            derivative=derivative,
-            pred_original_sample=pred_original_sample)
+            prev_sample=sample_prev, derivative=derivative, pred_original_sample=pred_original_sample
+        )
 
     def step_correct(
-            self,
-            model_output: paddle.Tensor,
-            sigma_hat: float,
-            sigma_prev: float,
-            sample_hat: paddle.Tensor,
-            sample_prev: paddle.Tensor,
-            derivative: paddle.Tensor,
-            return_dict: bool=True, ) -> Union[KarrasVeOutput, Tuple]:
+        self,
+        model_output: paddle.Tensor,
+        sigma_hat: float,
+        sigma_prev: float,
+        sample_hat: paddle.Tensor,
+        sample_prev: paddle.Tensor,
+        derivative: paddle.Tensor,
+        return_dict: bool = True,
+    ) -> Union[KarrasVeOutput, Tuple]:
         """
         Correct the predicted sample based on the output model_output of the network. TODO complete description
 
@@ -219,16 +219,14 @@ class KarrasVeScheduler(SchedulerMixin, ConfigMixin):
         """
         pred_original_sample = sample_prev + sigma_prev * model_output
         derivative_corr = (sample_prev - pred_original_sample) / sigma_prev
-        sample_prev = sample_hat + (sigma_prev - sigma_hat) * (
-            0.5 * derivative + 0.5 * derivative_corr)
+        sample_prev = sample_hat + (sigma_prev - sigma_hat) * (0.5 * derivative + 0.5 * derivative_corr)
 
         if not return_dict:
             return (sample_prev, derivative)
 
         return KarrasVeOutput(
-            prev_sample=sample_prev,
-            derivative=derivative,
-            pred_original_sample=pred_original_sample)
+            prev_sample=sample_prev, derivative=derivative, pred_original_sample=pred_original_sample
+        )
 
     def add_noise(self, original_samples, noise, timesteps):
         raise NotImplementedError()
