@@ -14,6 +14,7 @@
 # limitations under the License.
 
 import inspect
+import os
 import tempfile
 import unittest
 import unittest.mock as mock
@@ -25,9 +26,14 @@ import requests_mock
 from requests.exceptions import HTTPError
 
 from ppdiffusers.models import UNet2DConditionModel
+from ppdiffusers.models.attention_processor import (
+    AttnProcessor,
+    AttnProcessor2_5,
+    XFormersAttnProcessor,
+)
 from ppdiffusers.training_utils import EMAModel
 from ppdiffusers.utils import logging
-from ppdiffusers.utils.testing_utils import CaptureLogger
+from ppdiffusers.utils.testing_utils import CaptureLogger, nightly, require_paddle_gpu
 
 
 class ModelUtilsTest(unittest.TestCase):
@@ -45,16 +51,17 @@ class ModelUtilsTest(unittest.TestCase):
         response_mock.raise_for_status.side_effect = HTTPError
         response_mock.json.return_value = {}
         orig_model = UNet2DConditionModel.from_pretrained(
-            "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="unet")
+            "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="unet"
+        )
         with mock.patch("requests.request", return_value=response_mock):
             model = UNet2DConditionModel.from_pretrained(
-                "hf-internal-testing/tiny-stable-diffusion-torch",
-                subfolder="unet",
-                local_files_only=True)
+                "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="unet", local_files_only=True
+            )
         for p1, p2 in zip(orig_model.parameters(), model.parameters()):
             if (p1 != p2).cast("int64").sum() > 0:
                 assert False, "Parameters not the same!"
 
+    @nightly
     def test_one_request_upon_cached(self):
         import ppdiffusers
 
@@ -67,13 +74,12 @@ class ModelUtilsTest(unittest.TestCase):
                     subfolder="unet",
                     cache_dir=tmpdirname,
                     from_hf_hub=True,
-                    from_diffusers=True, )
+                    from_diffusers=True,
+                )
 
             download_requests = [r.method for r in m.request_history]
-            assert download_requests.count(
-                "HEAD") == 2, "2 HEAD requests one for config, one for model"
-            assert download_requests.count(
-                "GET") == 2, "2 GET requests one for config, one for model"
+            assert download_requests.count("HEAD") == 2, "2 HEAD requests one for config, one for model"
+            assert download_requests.count("GET") == 2, "2 GET requests one for config, one for model"
 
             with requests_mock.mock(real_http=True) as m:
                 UNet2DConditionModel.from_pretrained(
@@ -81,7 +87,8 @@ class ModelUtilsTest(unittest.TestCase):
                     subfolder="unet",
                     cache_dir=tmpdirname,
                     from_hf_hub=True,
-                    from_diffusers=True, )
+                    from_diffusers=True,
+                )
 
             cache_requests = [r.method for r in m.request_history]
             # TODO check this
@@ -92,15 +99,15 @@ class ModelUtilsTest(unittest.TestCase):
         ppdiffusers.utils.import_utils._safetensors_available = True
 
     def test_weight_overwrite(self):
-        with tempfile.TemporaryDirectory() as tmpdirname, self.assertRaises(
-                RuntimeError) as error_context:
+        with tempfile.TemporaryDirectory() as tmpdirname, self.assertRaises(RuntimeError) as error_context:
             UNet2DConditionModel.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch",
                 subfolder="unet",
                 cache_dir=tmpdirname,
                 in_channels=9,
-                from_hf_hub=True,
-                from_diffusers=True, )
+                # from_hf_hub=True,
+                # from_diffusers=True,
+            )
 
         # make sure that error message states what keys are missing
         assert "size mismatch" in str(error_context.exception)
@@ -113,13 +120,41 @@ class ModelUtilsTest(unittest.TestCase):
                 in_channels=9,
                 low_cpu_mem_usage=False,
                 ignore_mismatched_sizes=True,
-                from_hf_hub=True,
-                from_diffusers=True, )
+                # from_hf_hub=True,
+                # from_diffusers=True,
+            )
 
         assert model.config.in_channels == 9
 
 
+class UNetTesterMixin:
+    def test_forward_signature(self):
+        init_dict, _ = self.prepare_init_args_and_inputs_for_common()
+        model = self.model_class(**init_dict)
+        signature = inspect.signature(model.forward)
+        arg_names = [*signature.parameters.keys()]
+        expected_arg_names = ["sample", "timestep"]
+        self.assertListEqual(arg_names[:2], expected_arg_names)
+
+    def test_forward_with_norm_groups(self):
+        init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
+        init_dict["norm_num_groups"] = 16
+        init_dict["block_out_channels"] = 16, 32
+        model = self.model_class(**init_dict)
+        model.eval()
+        with paddle.no_grad():
+            output = model(**inputs_dict)
+            if isinstance(output, dict):
+                output = output.to_tuple()[0]
+        self.assertIsNotNone(output)
+        expected_shape = inputs_dict["sample"].shape
+        self.assertEqual(output.shape, expected_shape, "Input and output shapes do not match")
+
+
 class ModelTesterMixin:
+    main_input_name = None  # overwrite in model specific tester class
+    base_precision = 1e-3
+
     def test_from_save_pretrained(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
         model = self.model_class(**init_dict)
@@ -134,13 +169,12 @@ class ModelTesterMixin:
         with paddle.no_grad():
             image = model(**inputs_dict)
             if isinstance(image, dict):
-                image = image.sample
+                image = image.to_tuple()[0]
             new_image = new_model(**inputs_dict)
             if isinstance(new_image, dict):
-                new_image = new_image.sample
+                new_image = new_image.to_tuple()[0]
         max_diff = (image - new_image).abs().sum().item()
-        self.assertLessEqual(max_diff, 5e-05,
-                             "Models give different forward passes")
+        self.assertLessEqual(max_diff, 1e-01, "Models give different forward passes")
 
     def test_getattr_is_correct(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
@@ -150,7 +184,7 @@ class ModelTesterMixin:
         model.dummy_attribute = 5
         model.register_to_config(test_attribute=5)
 
-        logger = logging.get_logger("diffusers.models.modeling_utils")
+        logger = logging.get_logger("ppdiffusers.models.modeling_utils")
         # 30 for warning
         logger.setLevel(30)
         with CaptureLogger(logger) as cap_logger:
@@ -161,7 +195,7 @@ class ModelTesterMixin:
         # no warning should be thrown
         assert cap_logger.out == ""
 
-        logger = logging.get_logger("diffusers.models.modeling_utils")
+        logger = logging.get_logger("ppdiffusers.models.modeling_utils")
         # 30 for warning
         logger.setLevel(30)
         with CaptureLogger(logger) as cap_logger:
@@ -183,9 +217,47 @@ class ModelTesterMixin:
         with self.assertRaises(AttributeError) as error:
             model.does_not_exist
 
-        assert str(
-            error.exception
-        ) == f"'{type(model).__name__}' object has no attribute 'does_not_exist'"
+        assert str(error.exception) == f"'{type(model).__name__}' object has no attribute 'does_not_exist'"
+
+    @require_paddle_gpu
+    def test_set_attn_processor_for_determinism(self):
+        os.environ["FLAGS_cudnn_deterministic"] = "False"
+        os.environ["FLAGS_cpu_deterministic"] = "False"
+
+        init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
+        model = self.model_class(**init_dict)
+        if not hasattr(model, "set_attn_processor"):
+            return
+        assert all(type(proc) == AttnProcessor2_5 for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_1 = model(**inputs_dict)[0]
+        model.set_default_attn_processor()
+        assert all(type(proc) == AttnProcessor for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_2 = model(**inputs_dict)[0]
+        model.enable_xformers_memory_efficient_attention()
+        assert all(type(proc) == XFormersAttnProcessor for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_3 = model(**inputs_dict)[0]
+        model.set_attn_processor(AttnProcessor2_5())
+        assert all(type(proc) == AttnProcessor2_5 for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_4 = model(**inputs_dict)[0]
+        model.set_attn_processor(AttnProcessor())
+        assert all(type(proc) == AttnProcessor for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_5 = model(**inputs_dict)[0]
+        model.set_attn_processor(XFormersAttnProcessor())
+        assert all(type(proc) == XFormersAttnProcessor for proc in model.attn_processors.values())
+        with paddle.no_grad():
+            output_6 = model(**inputs_dict)[0]
+        os.environ["FLAGS_cudnn_deterministic"] = "True"
+        os.environ["FLAGS_cpu_deterministic"] = "True"
+        assert paddle.allclose(x=output_2, y=output_1, atol=self.base_precision).item()
+        assert paddle.allclose(x=output_2, y=output_3, atol=self.base_precision).item()
+        assert paddle.allclose(x=output_2, y=output_4, atol=self.base_precision).item()
+        assert paddle.allclose(x=output_2, y=output_5, atol=self.base_precision).item()
+        assert paddle.allclose(x=output_2, y=output_6, atol=self.base_precision).item()
 
     def test_from_save_pretrained_variant(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
@@ -195,8 +267,7 @@ class ModelTesterMixin:
         model.eval()
         with tempfile.TemporaryDirectory() as tmpdirname:
             model.save_pretrained(tmpdirname, variant="fp16")
-            new_model = self.model_class.from_pretrained(
-                tmpdirname, variant="fp16")
+            new_model = self.model_class.from_pretrained(tmpdirname, variant="fp16")
             if hasattr(new_model, "set_default_attn_processor"):
                 new_model.set_default_attn_processor()
             # non-variant cannot be loaded
@@ -207,19 +278,18 @@ class ModelTesterMixin:
             # support diffusion_pytorch_model.bin and model_state.pdparams
             assert "Error no file named model_state.pdparams found in directory" in str(
                 error_context.exception
-            ) or "Error no file named diffusion_pytorch_model.bin found in directory" in str(
-                error_context.exception)
+            ) or "Error no file named diffusion_pytorch_model.bin found in directory" in str(error_context.exception)
         with paddle.no_grad():
 
             image = model(**inputs_dict)
             if isinstance(image, dict):
-                image = image.sample
+                image = image.to_tuple()[0]
+
             new_image = new_model(**inputs_dict)
             if isinstance(new_image, dict):
-                new_image = new_image.sample
+                new_image = new_image.to_tuple()[0]
         max_diff = (image - new_image).abs().sum().item()
-        self.assertLessEqual(max_diff, 5e-05,
-                             "Models give different forward passes")
+        self.assertLessEqual(max_diff, 1e-01, "Models give different forward passes")
 
     def test_from_save_pretrained_dtype(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
@@ -230,30 +300,28 @@ class ModelTesterMixin:
             with tempfile.TemporaryDirectory() as tmpdirname:
                 model.to(dtype=dtype)
                 model.save_pretrained(tmpdirname)
-                new_model = self.model_class.from_pretrained(
-                    tmpdirname, paddle_dtype=dtype)
+                new_model = self.model_class.from_pretrained(tmpdirname, paddle_dtype=dtype)
                 assert new_model.dtype == dtype
-                new_model = self.model_class.from_pretrained(
-                    tmpdirname, paddle_dtype=dtype)
+                new_model = self.model_class.from_pretrained(tmpdirname, paddle_dtype=dtype)
                 assert new_model.dtype == dtype
 
-    def test_determinism(self):
+    def test_determinism(self, expected_max_diff=1e-4):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
         model = self.model_class(**init_dict)
         model.eval()
         with paddle.no_grad():
             first = model(**inputs_dict)
             if isinstance(first, dict):
-                first = first.sample
+                first = first.to_tuple()[0]
             second = model(**inputs_dict)
             if isinstance(second, dict):
-                second = second.sample
+                second = second.to_tuple()[0]
         out_1 = first.cpu().numpy()
         out_2 = second.cpu().numpy()
         out_1 = out_1[~np.isnan(out_1)]
         out_2 = out_2[~np.isnan(out_2)]
         max_diff = np.amax(np.abs(out_1 - out_2))
-        self.assertLessEqual(max_diff, 1e-05)
+        self.assertLessEqual(max_diff, expected_max_diff)
 
     def test_output(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
@@ -262,41 +330,25 @@ class ModelTesterMixin:
         with paddle.no_grad():
             output = model(**inputs_dict)
             if isinstance(output, dict):
-                output = output.sample
+                output = output.to_tuple()[0]
         self.assertIsNotNone(output)
-        expected_shape = inputs_dict["sample"].shape
-        self.assertEqual(output.shape, expected_shape,
-                         "Input and output shapes do not match")
-
-    def test_forward_with_norm_groups(self):
-        init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
-        init_dict["norm_num_groups"] = 16
-        init_dict["block_out_channels"] = 16, 32
-        model = self.model_class(**init_dict)
-        model.eval()
-        with paddle.no_grad():
-            output = model(**inputs_dict)
-            if isinstance(output, dict):
-                output = output.sample
-        self.assertIsNotNone(output)
-        expected_shape = inputs_dict["sample"].shape
-        self.assertEqual(output.shape, expected_shape,
-                         "Input and output shapes do not match")
-
-    def test_forward_signature(self):
-        init_dict, _ = self.prepare_init_args_and_inputs_for_common()
-        model = self.model_class(**init_dict)
-        signature = inspect.signature(model.forward)
-        arg_names = [*signature.parameters.keys()]
-        expected_arg_names = ["sample", "timestep"]
-        self.assertListEqual(arg_names[:2], expected_arg_names)
+        # input & output have to have the same shape
+        input_tensor = inputs_dict[self.main_input_name]
+        expected_shape = input_tensor.shape
+        self.assertEqual(output.shape, expected_shape, "Input and output shapes do not match")
 
     def test_model_from_pretrained(self):
         init_dict, inputs_dict = self.prepare_init_args_and_inputs_for_common()
         model = self.model_class(**init_dict)
         model.eval()
+
+        # test if the model can be loaded from the config
+        # and has all the expected shape
         with tempfile.TemporaryDirectory() as tmpdirname:
+
             model.save_pretrained(tmpdirname)
+            print("##############")
+            print(os.listdir(tmpdirname))
             new_model = self.model_class.from_pretrained(tmpdirname)
             new_model.eval()
         for param_name in model.state_dict().keys():
@@ -306,10 +358,10 @@ class ModelTesterMixin:
         with paddle.no_grad():
             output_1 = model(**inputs_dict)
             if isinstance(output_1, dict):
-                output_1 = output_1.sample
+                output_1 = output_1.to_tuple()[0]
             output_2 = new_model(**inputs_dict)
             if isinstance(output_2, dict):
-                output_2 = output_2.sample
+                output_2 = output_2.to_tuple()[0]
         self.assertEqual(output_1.shape, output_2.shape)
 
     def test_training(self):
@@ -318,9 +370,9 @@ class ModelTesterMixin:
         model.train()
         output = model(**inputs_dict)
         if isinstance(output, dict):
-            output = output.sample
-        noise = paddle.randn(
-            shape=list((inputs_dict["sample"].shape[0], ) + self.output_shape))
+            output = output.to_tuple()[0]
+        input_tensor = inputs_dict[self.main_input_name]
+        noise = paddle.randn(shape=(input_tensor.shape[0],) + self.output_shape)
         loss = paddle.nn.functional.mse_loss(input=output, label=noise)
         loss.backward()
 
@@ -331,9 +383,9 @@ class ModelTesterMixin:
         ema_model = EMAModel(model.parameters())
         output = model(**inputs_dict)
         if isinstance(output, dict):
-            output = output.sample
-        noise = paddle.randn(
-            shape=list((inputs_dict["sample"].shape[0], ) + self.output_shape))
+            output = output.to_tuple()[0]
+        input_tensor = inputs_dict[self.main_input_name]
+        noise = paddle.randn(shape=(input_tensor.shape[0],) + self.output_shape)
         loss = paddle.nn.functional.mse_loss(input=output, label=noise)
         loss.backward()
         ema_model.step(model.parameters())
@@ -345,21 +397,18 @@ class ModelTesterMixin:
 
         def recursive_check(tuple_object, dict_object):
             if isinstance(tuple_object, (List, Tuple)):
-                for tuple_iterable_value, dict_iterable_value in zip(
-                        tuple_object, dict_object.values()):
+                for tuple_iterable_value, dict_iterable_value in zip(tuple_object, dict_object.values()):
                     recursive_check(tuple_iterable_value, dict_iterable_value)
             elif isinstance(tuple_object, Dict):
-                for tuple_iterable_value, dict_iterable_value in zip(
-                        tuple_object.values(), dict_object.values()):
+                for tuple_iterable_value, dict_iterable_value in zip(tuple_object.values(), dict_object.values()):
                     recursive_check(tuple_iterable_value, dict_iterable_value)
             elif tuple_object is None:
                 return
             else:
                 self.assertTrue(
                     paddle.allclose(
-                        set_nan_tensor_to_zero(tuple_object),
-                        set_nan_tensor_to_zero(dict_object),
-                        atol=1e-05),
+                        set_nan_tensor_to_zero(tuple_object), set_nan_tensor_to_zero(dict_object), atol=1e-05
+                    ),
                     msg=f"Tuple and dict output are not equal. Difference: {paddle.max(x=paddle.abs(x=tuple_object - dict_object))}. Tuple has `nan`: {paddle.isnan(x=tuple_object).any()} and `inf`: {paddle.isinf(x=tuple_object)}. Dict has `nan`: {paddle.isnan(x=dict_object).any()} and `inf`: {paddle.isinf(x=dict_object)}.",
                 )
 
@@ -383,8 +432,7 @@ class ModelTesterMixin:
         self.assertFalse(model.is_gradient_checkpointing)
 
     def test_deprecated_kwargs(self):
-        has_kwarg_in_model_class = "kwargs" in inspect.signature(
-            self.model_class.__init__).parameters
+        has_kwarg_in_model_class = "kwargs" in inspect.signature(self.model_class.__init__).parameters
         has_deprecated_kwarg = len(self.model_class._deprecated_kwargs) > 0
         if has_kwarg_in_model_class and not has_deprecated_kwarg:
             raise ValueError(
