@@ -19,12 +19,16 @@ import paddle
 
 from ppdiffusers import VQModel
 from ppdiffusers.utils import floats_tensor
+from ppdiffusers.utils.testing_utils import enable_full_determinism
 
-from .test_modeling_common import ModelTesterMixin
+from .test_modeling_common import ModelTesterMixin, UNetTesterMixin
+
+enable_full_determinism()
 
 
-class VQModelTests(ModelTesterMixin, unittest.TestCase):
+class VQModelTests(ModelTesterMixin, UNetTesterMixin, unittest.TestCase):
     model_class = VQModel
+    main_input_name = "sample"
 
     @property
     def dummy_input(self, sizes=(32, 32)):
@@ -60,8 +64,7 @@ class VQModelTests(ModelTesterMixin, unittest.TestCase):
         pass
 
     def test_from_pretrained_hub(self):
-        model, loading_info = VQModel.from_pretrained(
-            "fusing/vqgan-dummy", output_loading_info=True)
+        model, loading_info = VQModel.from_pretrained("fusing/vqgan-dummy", output_loading_info=True)
         self.assertIsNotNone(model)
         self.assertEqual(len(loading_info["missing_keys"]), 0)
         image = model(**self.dummy_input)
@@ -71,24 +74,21 @@ class VQModelTests(ModelTesterMixin, unittest.TestCase):
         model = VQModel.from_pretrained("fusing/vqgan-dummy")
         model.eval()
         paddle.seed(0)
-        image = paddle.randn(shape=[
-            1, model.config.in_channels, model.config.sample_size,
-            model.config.sample_size
-        ])
+        image = paddle.randn(shape=[1, model.config.in_channels, model.config.sample_size, model.config.sample_size])
         with paddle.no_grad():
             output = model(image).sample
         output_slice = output[0, -1, -3:, -3:].flatten().cpu()
-        expected_output_slice = paddle.to_tensor([
-            -0.027147896587848663,
-            -0.41129639744758606,
-            -0.17730756103992462,
-            -0.5245445370674133,
-            -0.2423611730337143,
-            -0.3957087993621826,
-            -0.16461530327796936,
-            -0.06902074813842773,
-            -0.01736617460846901,
-        ])
-        self.assertTrue(
-            paddle.allclose(
-                output_slice, expected_output_slice, atol=0.01))
+        expected_output_slice = paddle.to_tensor(
+            [
+                -0.027147896587848663,
+                -0.41129639744758606,
+                -0.17730756103992462,
+                -0.5245445370674133,
+                -0.2423611730337143,
+                -0.3957087993621826,
+                -0.16461530327796936,
+                -0.06902074813842773,
+                -0.01736617460846901,
+            ]
+        )
+        self.assertTrue(paddle.allclose(output_slice, expected_output_slice, atol=0.01))
