@@ -17,10 +17,16 @@ import unittest
 
 import numpy as np
 import paddle
-
 from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel
+
 from ppdiffusers import DDIMScheduler, LDMPipeline, UNet2DModel, VQModel
-from ppdiffusers.utils.testing_utils import require_paddle, slow
+from ppdiffusers.utils.testing_utils import (
+    enable_full_determinism,
+    require_paddle,
+    slow,
+)
+
+enable_full_determinism()
 
 
 class LDMPipelineFastTests(unittest.TestCase):
@@ -34,7 +40,8 @@ class LDMPipelineFastTests(unittest.TestCase):
             in_channels=3,
             out_channels=3,
             down_block_types=("DownBlock2D", "AttnDownBlock2D"),
-            up_block_types=("AttnUpBlock2D", "UpBlock2D"), )
+            up_block_types=("AttnUpBlock2D", "UpBlock2D"),
+        )
         return model
 
     @property
@@ -46,7 +53,8 @@ class LDMPipelineFastTests(unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=3, )
+            latent_channels=3,
+        )
         return model
 
     @property
@@ -61,7 +69,8 @@ class LDMPipelineFastTests(unittest.TestCase):
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000, )
+            vocab_size=1000,
+        )
         return CLIPTextModel(config).eval()
 
     def test_inference_uncond(self):
@@ -71,25 +80,18 @@ class LDMPipelineFastTests(unittest.TestCase):
         ldm = LDMPipeline(unet=unet, vqvae=vae, scheduler=scheduler)
         ldm.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
-        image = ldm(generator=generator,
-                    num_inference_steps=2,
-                    output_type="numpy").images
+        image = ldm(generator=generator, num_inference_steps=2, output_type="numpy").images
         generator = paddle.Generator().manual_seed(0)
-        image_from_tuple = ldm(generator=generator,
-                               num_inference_steps=2,
-                               output_type="numpy",
-                               return_dict=False)[0]
+        image_from_tuple = ldm(generator=generator, num_inference_steps=2, output_type="numpy", return_dict=False)[0]
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array([
-            0.827049, 1.0, 0.6244688, 0.7729403, 1.0, 0.73071766, 0.6108738,
-            0.9107263, 0.7249622
-        ])
+        expected_slice = np.array(
+            [0.827049, 1.0, 0.6244688, 0.7729403, 1.0, 0.73071766, 0.6108738, 0.9107263, 0.7249622]
+        )
         tolerance = 0.01
         assert np.abs(image_slice.flatten() - expected_slice).max() < tolerance
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max(
-        ) < tolerance
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < tolerance
 
 
 @slow
@@ -99,14 +101,11 @@ class LDMPipelineIntegrationTests(unittest.TestCase):
         ldm = LDMPipeline.from_pretrained("CompVis/ldm-celebahq-256")
         ldm.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
-        image = ldm(generator=generator,
-                    num_inference_steps=5,
-                    output_type="numpy").images
+        image = ldm(generator=generator, num_inference_steps=5, output_type="numpy").images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 256, 256, 3)
-        expected_slice = np.array([
-            0.59802866, 0.61698544, 0.62753576, 0.6128236, 0.60961217, 0.617262,
-            0.6060791, 0.60261935, 0.6129079
-        ])
+        expected_slice = np.array(
+            [0.59802866, 0.61698544, 0.62753576, 0.6128236, 0.60961217, 0.617262, 0.6060791, 0.60261935, 0.6129079]
+        )
         tolerance = 0.01
         assert np.abs(image_slice.flatten() - expected_slice).max() < tolerance
