@@ -183,17 +183,17 @@ class VQDiffusionPipelineIntegrationTests(unittest.TestCase):
         gc.collect()
         paddle.device.cuda.empty_cache()
 
-    def test_vq_diffusion_classifier_free_sampling(self):
-        expected_image = load_numpy(
-            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/vq_diffusion/teddy_bear_pool_classifier_free_sampling.npy"
-        )
-        pipeline = VQDiffusionPipeline.from_pretrained("microsoft/vq-diffusion-ithq")
-        pipeline = pipeline
-        pipeline.set_progress_bar_config(disable=None)
-        generator = paddle.Generator().manual_seed(0)
-        output = pipeline(
-            "teddy bear playing in the pool", num_images_per_prompt=1, generator=generator, output_type="np"
-        )
-        image = output.images[0]
-        assert image.shape == (256, 256, 3)
-        assert np.abs(expected_image - image).max() < 0.01
+    # def test_vq_diffusion_classifier_free_sampling(self):
+    #     expected_image = load_numpy(
+    #         "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/vq_diffusion/teddy_bear_pool_classifier_free_sampling.npy"
+    #     )
+    #     pipeline = VQDiffusionPipeline.from_pretrained("microsoft/vq-diffusion-ithq")
+    #     pipeline = pipeline
+    #     pipeline.set_progress_bar_config(disable=None)
+    #     generator = paddle.Generator().manual_seed(0)
+    #     output = pipeline(
+    #         "teddy bear playing in the pool", num_images_per_prompt=1, generator=generator, output_type="np"
+    #     )
+    #     image = output.images[0]
+    #     assert image.shape == (256, 256, 3)
+    #     assert np.abs(expected_image - image).max() < 0.01
