@@ -20,14 +20,15 @@ from ppdiffusers import (
     DEISMultistepScheduler,
     DPMSolverMultistepScheduler,
     DPMSolverSinglestepScheduler,
-    UniPCMultistepScheduler, )
+    UniPCMultistepScheduler,
+)
 
 from .test_schedulers import SchedulerCommonTest
 
 
 class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
-    scheduler_classes = (DPMSolverMultistepScheduler, )
-    forward_default_kwargs = (("num_inference_steps", 25), )
+    scheduler_classes = (DPMSolverMultistepScheduler,)
+    forward_default_kwargs = (("num_inference_steps", 25),)
 
     def get_scheduler_config(self, **kwargs):
         config = {
@@ -42,6 +43,8 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
             "algorithm_type": "dpmsolver++",
             "solver_type": "midpoint",
             "lower_order_final": False,
+            "lambda_min_clipped": -float("inf"),
+            "variance_type": None,
         }
 
         config.update(**kwargs)
@@ -52,39 +55,28 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
         num_inference_steps = kwargs.pop("num_inference_steps", None)
         sample = self.dummy_sample
         residual = 0.1 * sample
-        dummy_past_residuals = [
-            residual + 0.2, residual + 0.15, residual + 0.10
-        ]
+        dummy_past_residuals = [residual + 0.2, residual + 0.15, residual + 0.10]
 
         for scheduler_class in self.scheduler_classes:
             scheduler_config = self.get_scheduler_config(**config)
             scheduler = scheduler_class(**scheduler_config)
             scheduler.set_timesteps(num_inference_steps)
             # copy over dummy past residuals
-            scheduler.model_outputs = dummy_past_residuals[:scheduler.config.
-                                                           solver_order]
+            scheduler.model_outputs = dummy_past_residuals[: scheduler.config.solver_order]
 
             with tempfile.TemporaryDirectory() as tmpdirname:
                 scheduler.save_config(tmpdirname)
                 new_scheduler = scheduler_class.from_pretrained(tmpdirname)
                 new_scheduler.set_timesteps(num_inference_steps)
                 # copy over dummy past residuals
-                new_scheduler.model_outputs = dummy_past_residuals[:
-                                                                   new_scheduler.
-                                                                   config.
-                                                                   solver_order]
+                new_scheduler.model_outputs = dummy_past_residuals[: new_scheduler.config.solver_order]
 
             output, new_output = sample, sample
-            for t in range(time_step,
-                           time_step + scheduler.config.solver_order + 1):
-                output = scheduler.step(residual, t, output,
-                                        **kwargs).prev_sample
-                new_output = new_scheduler.step(residual, t, new_output,
-                                                **kwargs).prev_sample
+            for t in range(time_step, time_step + scheduler.config.solver_order + 1):
+                output = scheduler.step(residual, t, output, **kwargs).prev_sample
+                new_output = new_scheduler.step(residual, t, new_output, **kwargs).prev_sample
 
-                assert paddle.sum(paddle.abs(
-                    output -
-                    new_output)) < 1e-5, "Scheduler outputs are not identical"
+                assert paddle.sum(paddle.abs(output - new_output)) < 1e-5, "Scheduler outputs are not identical"
 
     def test_from_save_pretrained(self):
         pass
@@ -94,9 +86,7 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
         num_inference_steps = kwargs.pop("num_inference_steps", None)
         sample = self.dummy_sample
         residual = 0.1 * sample
-        dummy_past_residuals = [
-            residual + 0.2, residual + 0.15, residual + 0.10
-        ]
+        dummy_past_residuals = [residual + 0.2, residual + 0.15, residual + 0.10]
 
         for scheduler_class in self.scheduler_classes:
             scheduler_config = self.get_scheduler_config()
@@ -104,8 +94,7 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
             scheduler.set_timesteps(num_inference_steps)
 
             # copy over dummy past residuals (must be after setting timesteps)
-            scheduler.model_outputs = dummy_past_residuals[:scheduler.config.
-                                                           solver_order]
+            scheduler.model_outputs = dummy_past_residuals[: scheduler.config.solver_order]
 
             with tempfile.TemporaryDirectory() as tmpdirname:
                 scheduler.save_config(tmpdirname)
@@ -114,18 +103,12 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
                 new_scheduler.set_timesteps(num_inference_steps)
 
                 # copy over dummy past residual (must be after setting timesteps)
-                new_scheduler.model_outputs = dummy_past_residuals[:
-                                                                   new_scheduler.
-                                                                   config.
-                                                                   solver_order]
+                new_scheduler.model_outputs = dummy_past_residuals[: new_scheduler.config.solver_order]
 
-            output = scheduler.step(residual, time_step, sample,
-                                    **kwargs).prev_sample
-            new_output = new_scheduler.step(residual, time_step, sample,
-                                            **kwargs).prev_sample
+            output = scheduler.step(residual, time_step, sample, **kwargs).prev_sample
+            new_output = new_scheduler.step(residual, time_step, sample, **kwargs).prev_sample
 
-            assert paddle.sum(paddle.abs(output - new_output)
-                              ) < 1e-5, "Scheduler outputs are not identical"
+            assert paddle.sum(paddle.abs(output - new_output)) < 1e-5, "Scheduler outputs are not identical"
 
     def full_loop(self, scheduler=None, **config):
         if scheduler is None:
@@ -141,7 +124,6 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
         for i, t in enumerate(scheduler.timesteps):
             residual = model(sample, t)
             sample = scheduler.step(residual, t, sample).prev_sample
-
         return sample
 
     def test_step_shape(self):
@@ -156,27 +138,20 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
             sample = self.dummy_sample
             residual = 0.1 * sample
 
-            if num_inference_steps is not None and hasattr(scheduler,
-                                                           "set_timesteps"):
+            if num_inference_steps is not None and hasattr(scheduler, "set_timesteps"):
                 scheduler.set_timesteps(num_inference_steps)
-            elif num_inference_steps is not None and not hasattr(
-                    scheduler, "set_timesteps"):
+            elif num_inference_steps is not None and not hasattr(scheduler, "set_timesteps"):
                 kwargs["num_inference_steps"] = num_inference_steps
 
             # copy over dummy past residuals (must be done after set_timesteps)
-            dummy_past_residuals = [
-                residual + 0.2, residual + 0.15, residual + 0.10
-            ]
-            scheduler.model_outputs = dummy_past_residuals[:scheduler.config.
-                                                           solver_order]
+            dummy_past_residuals = [residual + 0.2, residual + 0.15, residual + 0.10]
+            scheduler.model_outputs = dummy_past_residuals[: scheduler.config.solver_order]
 
             time_step_0 = scheduler.timesteps[5]
             time_step_1 = scheduler.timesteps[6]
 
-            output_0 = scheduler.step(residual, time_step_0, sample,
-                                      **kwargs).prev_sample
-            output_1 = scheduler.step(residual, time_step_1, sample,
-                                      **kwargs).prev_sample
+            output_0 = scheduler.step(residual, time_step_0, sample, **kwargs).prev_sample
+            output_1 = scheduler.step(residual, time_step_1, sample, **kwargs).prev_sample
 
             self.assertEqual(output_0.shape, sample.shape)
             self.assertEqual(output_0.shape, output_1.shape)
@@ -197,38 +172,51 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
                             sample_max_value=threshold,
                             algorithm_type="dpmsolver++",
                             solver_order=order,
-                            solver_type=solver_type, )
+                            solver_type=solver_type,
+                        )
 
     def test_prediction_type(self):
         for prediction_type in ["epsilon", "v_prediction"]:
             self.check_over_configs(prediction_type=prediction_type)
 
     def test_solver_order_and_type(self):
-        for algorithm_type in ["dpmsolver", "dpmsolver++"]:
+        for algorithm_type in ["dpmsolver", "dpmsolver++", "sde-dpmsolver", "sde-dpmsolver++"]:
             for solver_type in ["midpoint", "heun"]:
                 for order in [1, 2, 3]:
                     for prediction_type in ["epsilon", "sample"]:
-                        self.check_over_configs(
-                            solver_order=order,
-                            solver_type=solver_type,
-                            prediction_type=prediction_type,
-                            algorithm_type=algorithm_type, )
+                        if algorithm_type in ["sde-dpmsolver", "sde-dpmsolver++"]:
+                            if order == 3:
+                                continue
+                        else:
+                            self.check_over_configs(
+                                solver_order=order,
+                                solver_type=solver_type,
+                                prediction_type=prediction_type,
+                                algorithm_type=algorithm_type,
+                            )
                         sample = self.full_loop(
                             solver_order=order,
                             solver_type=solver_type,
                             prediction_type=prediction_type,
-                            algorithm_type=algorithm_type, )
-                        assert not paddle.isnan(sample).any(
-                        ), "Samples have nan numbers"
+                            algorithm_type=algorithm_type,
+                        )
+                        assert not paddle.isnan(sample).any(), "Samples have nan numbers"
 
     def test_lower_order_final(self):
         self.check_over_configs(lower_order_final=True)
         self.check_over_configs(lower_order_final=False)
 
+    def test_lambda_min_clipped(self):
+        self.check_over_configs(lambda_min_clipped=-float("inf"))
+        self.check_over_configs(lambda_min_clipped=-5.1)
+
+    def test_variance_type(self):
+        self.check_over_configs(variance_type=None)
+        self.check_over_configs(variance_type="learned_range")
+
     def test_inference_steps(self):
         for num_inference_steps in [1, 2, 3, 5, 10, 50, 100, 999, 1000]:
-            self.check_over_forward(
-                num_inference_steps=num_inference_steps, time_step=0)
+            self.check_over_forward(num_inference_steps=num_inference_steps, time_step=0)
 
     def test_full_loop_no_noise(self):
         sample = self.full_loop()
@@ -237,10 +225,7 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
         assert abs(result_mean.item() - 0.3301) < 1e-3
 
     def test_full_loop_no_noise_thres(self):
-        sample = self.full_loop(
-            thresholding=True,
-            dynamic_thresholding_ratio=0.87,
-            sample_max_value=0.5)
+        sample = self.full_loop(thresholding=True, dynamic_thresholding_ratio=0.87, sample_max_value=0.5)
         result_mean = paddle.mean(paddle.abs(sample))
 
         assert abs(result_mean.item() - 1.1364) < 1e-3
@@ -252,8 +237,7 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
         assert abs(result_mean.item() - 0.2251) < 1e-3
 
     def test_full_loop_with_karras_and_v_prediction(self):
-        sample = self.full_loop(
-            prediction_type="v_prediction", use_karras_sigmas=True)
+        sample = self.full_loop(prediction_type="v_prediction", use_karras_sigmas=True)
         result_mean = paddle.mean(paddle.abs(sample))
 
         assert abs(result_mean.item() - 0.2096) < 1e-3
@@ -279,8 +263,7 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
 
     def test_fp16_support(self):
         scheduler_class = self.scheduler_classes[0]
-        scheduler_config = self.get_scheduler_config(
-            thresholding=True, dynamic_thresholding_ratio=0)
+        scheduler_config = self.get_scheduler_config(thresholding=True, dynamic_thresholding_ratio=0)
         scheduler = scheduler_class(**scheduler_config)
 
         num_inference_steps = 10
@@ -301,5 +284,4 @@ class DPMSolverMultistepSchedulerTest(SchedulerCommonTest):
             scheduler = scheduler_class(**scheduler_config)
 
             scheduler.set_timesteps(scheduler.config.num_train_timesteps)
-            assert len(scheduler.timesteps.unique(
-            )) == scheduler.num_inference_steps
+            assert len(scheduler.timesteps.unique()) == scheduler.num_inference_steps
