@@ -20,7 +20,7 @@ from .test_schedulers import SchedulerCommonTest
 
 
 class LMSDiscreteSchedulerTest(SchedulerCommonTest):
-    scheduler_classes = (LMSDiscreteScheduler, )
+    scheduler_classes = (LMSDiscreteScheduler,)
     num_inference_steps = 10
 
     def get_scheduler_config(self, **kwargs):
@@ -39,8 +39,7 @@ class LMSDiscreteSchedulerTest(SchedulerCommonTest):
             self.check_over_configs(num_train_timesteps=timesteps)
 
     def test_betas(self):
-        for beta_start, beta_end in zip([0.00001, 0.0001, 0.001],
-                                        [0.0002, 0.002, 0.02]):
+        for beta_start, beta_end in zip([0.00001, 0.0001, 0.001], [0.0002, 0.002, 0.02]):
             self.check_over_configs(beta_start=beta_start, beta_end=beta_end)
 
     def test_schedules(self):
@@ -81,8 +80,7 @@ class LMSDiscreteSchedulerTest(SchedulerCommonTest):
 
     def test_full_loop_with_v_prediction(self):
         scheduler_class = self.scheduler_classes[0]
-        scheduler_config = self.get_scheduler_config(
-            prediction_type="v_prediction")
+        scheduler_config = self.get_scheduler_config(prediction_type="v_prediction")
         scheduler = scheduler_class(**scheduler_config)
 
         scheduler.set_timesteps(self.num_inference_steps)
@@ -127,3 +125,27 @@ class LMSDiscreteSchedulerTest(SchedulerCommonTest):
 
         assert abs(result_sum.item() - 1006.388) < 1e-2
         assert abs(result_mean.item() - 1.31) < 1e-3
+
+    def test_full_loop_device_karras_sigmas(self):
+            scheduler_class = self.scheduler_classes[0]
+            scheduler_config = self.get_scheduler_config()
+            scheduler = scheduler_class(**scheduler_config, use_karras_sigmas=True)
+
+            scheduler.set_timesteps(self.num_inference_steps)
+
+            model = self.dummy_model()
+            sample = self.dummy_sample_deter * scheduler.init_noise_sigma
+
+            for t in scheduler.timesteps:
+                sample = scheduler.scale_model_input(sample, t)
+
+                model_output = model(sample, t)
+
+                output = scheduler.step(model_output, t, sample)
+                sample = output.prev_sample
+
+            result_sum = paddle.sum(paddle.abs(sample))
+            result_mean = paddle.mean(paddle.abs(sample))
+
+            assert abs(result_sum.item() - 3812.9927) < 2e-2
+            assert abs(result_mean.item() - 4.9648) < 1e-3
\ No newline at end of file
